@@ -1,10 +1,19 @@
 
-context("Fuzzy tests")
 
+# how to debug
+# look for a 6 figure number in test output.
+# Run:
+#   library(huxtable)
+# Source `add_props()`, the `variations` data frame and the `hux_raw` huxtable.
+# run:
+#   hx_set <- add_props(hx_raw, variations[six_figure_no,])
+# compare outputs to something like
+# cat("tests/testthat/output-rds/various-outputs-six_figure_no-...")
+# or run quick_xxx functions on it
 
 expect_outputs_unchanged <- function (hx, idx) {
   info <- paste0("Index i = ", idx)
-  file <- file.path(test_path(), "example-rds", paste0("various-outputs-", idx))
+  file <- file.path(test_path(), "output-rds", paste0("various-outputs-", idx))
   # setting the width avoids problems that command line and RStudio tests have different
   # options(width)
   expect_known_value(to_screen(hx, min_width = 20, max_width = 80),
@@ -44,14 +53,25 @@ hx_raw <- hux(
   real = 1:3 + 0.005,
   char = letters[1:3],
   date = as.Date(1:3, origin = "1970-01-01"),
-  fact = factor(letters[4:6])
+  fact = factor(letters[4:6]),
+  add_colnames = TRUE
 )
 
 
 add_props <- function(hx, row) {
   props <- as.list(row)
   props$ht <- hx
-  hx_set <- do.call("set_cell_properties", props)
+  props_no_border <- props[! grepl("border", names(props))]
+  hx_set <- do.call("set_cell_properties", props_no_border)
+  if ("left_border" %in% names(props)) {
+    hx_set <- set_left_border(hx_set, props$left_border)
+  }
+  if ("left_border_style" %in% names(props)) {
+    hx_set <- set_left_border_style(hx_set, props$left_border_style)
+  }
+  if ("left_border_color" %in% names(props)) {
+    hx_set <- set_left_border_color(hx_set, props$left_border_color)
+  }
 
   return(hx_set)
 }
